/* BdfServer - Copyright (c) 2015-2023 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.importation.parsers.handlers;

import net.fichotheque.Subset;
import net.fichotheque.corpus.Corpus;
import net.fichotheque.thesaurus.metadata.ThesaurusLangChecker;
import net.fichotheque.thesaurus.policies.PolicyProvider;
import net.fichotheque.tools.corpus.FicheChangeBuilder;
import net.fichotheque.tools.importation.LiensImportBuilder;
import net.fichotheque.tools.importation.ParseResultBuilder;
import net.fichotheque.tools.importation.parsers.BdfErrorException;
import net.fichotheque.tools.importation.parsers.LiensParser;
import net.fichotheque.tools.importation.parsers.Row;
import net.fichotheque.tools.parsers.FicheParser;
import net.mapeadores.util.attr.AttributeChangeBuilder;
import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.text.LabelChangeBuilder;


/**
 *
 * @author Vincent Calame
 */
public final class HandlerUtils {

    private HandlerUtils() {

    }

    public static LabelChangeBuilder toChangeLabelHolderBuilder(LabelHandler[] labelHandlerArray, Row row, ParseResultBuilder parseResultBuilder, int rowNumber) {
        if (labelHandlerArray == null) {
            return null;
        }
        LabelChangeBuilder changeLabelHolderBuilder = new LabelChangeBuilder();
        for (LabelHandler labelHandler : labelHandlerArray) {
            try {
                labelHandler.handle(row, changeLabelHolderBuilder);
            } catch (BdfErrorException bee) {
                parseResultBuilder.addBdfError(bee.getKey(), bee.getText(), rowNumber);
            }
        }
        return changeLabelHolderBuilder;
    }

    public static AttributeChangeBuilder toAttributeChangeBuilder(AttributeHandler[] attributeHandlerArray, Row row) {
        if (attributeHandlerArray == null) {
            return null;
        }
        AttributeChangeBuilder attributeChangeBuilder = new AttributeChangeBuilder();
        for (AttributeHandler attributeHandler : attributeHandlerArray) {
            attributeHandler.handle(row, attributeChangeBuilder);
        }
        return attributeChangeBuilder;
    }

    public static LiensImportBuilder toLiensImportBuilder(CroisementHandlers croisementHandlers, Row row, Subset subset, Lang lang, PolicyProvider policyProvider, ThesaurusLangChecker thesaurusLangChecker) {
        if (croisementHandlers.isEmpty()) {
            return null;
        }
        LiensImportBuilder liensImportBuilder = new LiensImportBuilder();
        LiensParser liensParser = new LiensParser(subset, liensImportBuilder, lang, policyProvider, thesaurusLangChecker);
        croisementHandlers.handle(row, liensParser);
        return liensImportBuilder;
    }

    public static FicheChangeBuilder toFicheChangeBuilder(FicheHandler[] ficheHandlerArray, Row row, Corpus corpus, FicheParser.Parameters ficheParserParameters) {
        FicheChangeBuilder ficheChangeBuilder = new FicheChangeBuilder();
        FicheParser ficheParser = new FicheParser(ficheParserParameters, corpus, ficheChangeBuilder);
        if (ficheHandlerArray != null) {
            for (FicheHandler ficheHandler : ficheHandlerArray) {
                ficheHandler.handle(row, ficheParser);
            }
        }
        ficheParser.flushParsedSubfields();
        return ficheChangeBuilder;
    }

}
